import { createRouter, createWebHistory } from 'vue-router';
import store from '@/stores/counter';
import axios from 'axios';
const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: '/',
      redirect: '/login'
    },
    {
      path: '/login',
      name: 'login',
      meta: { title: '账号登录' },
      component: () => import('@/views/login/index.vue')
    },
    {
      path: '/register',
      name: 'register',
      meta: { title: '账号注册' },
      component: () => import('@/views/register/index.vue')
    },
    {
      path: '/homeIndex',
      meta: { title: '系统首页' },
      component: () => import('@/components/admin-frame/home.vue'),
      children: [
        {
          path: '/homeIndex',
          meta: { title: '系统首页' },
          component: () => import('@/views/home/index.vue')
        },
        {
          path: '/system/role',
          meta: { title: '角色管理' },
          component: () => import('@/views/system/role/index.vue')
        },
        {
          path: '/system/role/detail',
          meta: { title: '角色信息管理' },
          component: () => import('@/views/system/role/detail.vue')
        },
        {
          path: '/system/menus',
          meta: { title: '菜单管理' },
          component: () => import('@/views/system/menus/index.vue')
        },
        {
          path: '/system/dict',
          meta: { title: '字典管理' },
          component: () => import('@/views/system/dict/index.vue')
        },
        {
          path: '/system/region',
          meta: { title: '区域管理' },
          component: () => import('@/views/system/region/index.vue')
        },
        {
          path: '/system/dictData',
          meta: { title: '字典数据管理' },
          component: () => import('@/views/system/dictData/index.vue')
        },
        {
          path: '/config/info',
          meta: { title: '景区基本信息' },
          component: () => import('@/views/config/info/index.vue')
        },
        {
          path: '/config/module',
          meta: { title: '首页模块处理' },
          component: () => import('@/views/config/module/index.vue')
        },
        {
          path: '/config/map',
          meta: { title: '地图导览管理' },
          component: () => import('@/views/config/map/index.vue')
        },
        {
          path: '/user/user',
          meta: { title: '普通用户' },
          component: () => import('@/views/user/user/index.vue')
        },
        {
          path: '/user/chat',
          meta: { title: '聊天记录' },
          component: () => import('@/views/user/user/chat.vue')
        },
        {
          path: '/user/admin',
          meta: { title: '区域管理员' },
          component: () => import('@/views/user/admin/index.vue')
        },
        {
          path: '/admin/detail',
          meta: { title: '区域管理员信息管理' },
          component: () => import('@/views/user/admin/detail.vue')
        },
        {
          path: '/content/news',
          meta: { title: '新闻管理' },
          component: () => import('@/views/content/news/index.vue')
        },
        {
          path: '/content/activity',
          meta: { title: '活动管理' },
          component: () => import('@/views/content/activity/index.vue')
        },
        {
          path: '/content/article',
          meta: { title: '游玩攻略管理' },
          component: () => import('@/views/content/article/index.vue')
        },
        {
          path: '/content/article/detail',
          meta: { title: '游玩攻略信息管理' },
          component: () => import('@/views/content/article/detail.vue')
        },
        {
          path: '/content/notice',
          meta: { title: '公告管理' },
          component: () => import('@/views/content/notice/index.vue')
        },
        {
          path: '/basic/part',
          meta: { title: '信息管理' },
          component: () => import('@/views/basic/apart/detail.vue')
        },
        {
          path: '/basic/place',
          meta: { title: '景区景点管理' },
          component: () => import('@/views/basic/place/index.vue')
        },
        {
          path: '/basic/hotel',
          meta: { title: '酒店民宿管理' },
          component: () => import('@/views/basic/hotel/index.vue')
        },
        {
          path: '/basic/hotel/detail',
          meta: { title: '酒店民宿信息管理' },
          component: () => import('@/views/basic/hotel/detail.vue')
        },
        {
          path: '/basic/room',
          meta: { title: '房间信息管理' },
          component: () => import('@/views/basic/hotel/room.vue')
        },
        {
          path: '/basic/food',
          meta: { title: '餐饮场所管理' },
          component: () => import('@/views/basic/food/index.vue')
        },
        {
          path: '/basic/shop',
          meta: { title: '购物场所管理' },
          component: () => import('@/views/basic/shop/index.vue')
        },
        {
          path: '/basic/tourism',
          meta: { title: '特色旅游管理' },
          component: () => import('@/views/basic/tourism/index.vue')
        },
        {
          path: '/basic/delicacy',
          meta: { title: '特色美食管理' },
          component: () => import('@/views/basic/delicacy/index.vue')
        },
        {
          path: '/basic/souvenir',
          meta: { title: '纪念品管理' },
          component: () => import('@/views/basic/souvenir/index.vue')
        },
        {
          path: '/basic/toilet',
          meta: { title: '厕所管理' },
          component: () => import('@/views/basic/toilet/index.vue')
        },
        {
          path: '/basic/parking',
          meta: { title: '停车场管理' },
          component: () => import('@/views/basic/parking/index.vue')
        },
        {
          path: '/basic/medical',
          meta: { title: '医疗点管理' },
          component: () => import('@/views/basic/medical/index.vue')
        },
        {
          path: '/basic/media/audio',
          meta: { title: '音频管理' },
          component: () => import('@/views/basic/media/audio/index.vue')
        },
        {
          path: '/basic/media/video',
          meta: { title: '视频管理' },
          component: () => import('@/views/basic/media/video/index.vue')
        },
        {
          path: '/basic/media/url',
          meta: { title: '图片管理' },
          component: () => import('@/views/basic/media/url/index.vue')
        },
        {
          path: '/basic/comment',
          meta: { title: '评论管理' },
          component: () => import('@/views/basic/comment/index.vue')
        },
        {
          path: '/basic/ticket',
          meta: { title: '景区门票管理' },
          component: () => import('@/views/basic/ticket/index.vue')
        },
        {
          path: '/basic/ticket/detail',
          meta: { title: '景区门票信息管理' },
          component: () => import('@/views/basic/ticket/detail.vue')
        },
        {
          path: '/business/advert',
          meta: { title: '广告管理' },
          component: () => import('@/views/business/advert/index.vue')
        },
        {
          path: '/business/vote',
          meta: { title: '投票管理' },
          component: () => import('@/views/business/vote/index.vue')
        },
        {
          path: '/business/market',
          meta: { title: '营销管理' },
          component: () => import('@/views/business/market/index.vue')
        },
        {
          path: '/business/coupon',
          meta: { title: '优惠卷管理' },
          component: () => import('@/views/business/coupon/index.vue')
        },
        {
          path: '/customer/intelligence',
          meta: { title: '智能客服管理' },
          component: () => import('@/views/customer/intelligence/index.vue')
        },
        {
          path: '/customer/problem',
          meta: { title: 'FAQ问答管理' },
          component: () => import('@/views/customer/problem/index.vue')
        },
        {
          path: '/problem/opinion',
          meta: { title: '意见反馈管理' },
          component: () => import('@/views/problem/opinion/index.vue')
        },
        {
          path: '/problem/questionnaire',
          meta: { title: '问卷调查管理' },
          component: () => import('@/views/problem/questionnaire/index.vue')
        },
        {
          path: '/order/index',
          meta: { title: '订单管理' },
          component: () => import('@/views/order/index.vue')
        },
        {
          path: '/order/detail',
          meta: { title: '订单信息管理' },
          component: () => import('@/views/order/detail.vue')
        },
        {
          path: '/order/rate',
          meta: { title: '订单评价管理' },
          component: () => import('@/views/order/rate.vue')
        },
        {
          path: '/order/after',
          meta: { title: '订单售后管理' },
          component: () => import('@/views/order/after.vue')
        },
        {
          path: '/acccount/information',
          meta: { title: '账号信息' },
          component: () => import('@/views/acccount/information/index.vue')
        },
        {
          path: '/acccount/updatepd',
          meta: { title: '修改密码' },
          component: () => import('@/views/acccount/updatepd/index.vue')
        }
      ]
    }
  ]
});
router.beforeEach(async (to, from, next) => {
  document.title = `${to.meta.title} `;
  const token = localStorage.getItem('token');
  if (to.name != 'login' && to.name != 'register') {
    if (token) {
      const res = await axios.request({
        method: 'get',
        url: '/travel/v1/api/tool/token',
        responseType: 'json',
        headers: {
          token: token
        }
      });
      if (res.data.errcode == '0') {
        store.commit('setUser', res.data.data, { root: true });
      }
      next();
    } else next('/login');
  } else next();
});

export default router;
